searchData={"items":[{"type":"module","title":"DHCP","doc":"Dynamic Host Configuration Protocol\n\n[RFC2131](https://datatracker.ietf.org/doc/html/rfc2131)\n\nThe Dynamic Host Configuration Protocol (DHCP) provides configuration\nparameters to Internet hosts.  DHCP consists of two components: a\nprotocol for delivering host-specific configuration parameters from a\nDHCP server to a host and a mechanism for allocation of network\naddresses to hosts.\n\nDHCP is built on a client-server model, where designated DHCP server\nhosts allocate network addresses and deliver configuration parameters\nto dynamically configured hosts.  Throughout the remainder of this\ndocument, the term \"server\" refers to a host providing initialization\nparameters through DHCP, and the term \"client\" refers to a host\nrequesting initialization parameters from a DHCP server.","ref":"DHCP.html"},{"type":"function","title":"DHCP.to_iodata/1","doc":"","ref":"DHCP.html#to_iodata/1"},{"type":"module","title":"DHCP.Message","doc":"# DHCP Message\n\n    Format of a DHCP message\n\n    0                   1                   2                   3\n    0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1\n    +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n    |     op (1)    |   htype (1)   |   hlen (1)    |   hops (1)    |\n    +---------------+---------------+---------------+---------------+\n    |                            xid (4)                            |\n    +-------------------------------+-------------------------------+\n    |           secs (2)            |           flags (2)           |\n    +-------------------------------+-------------------------------+\n    |                          ciaddr  (4)                          |\n    +---------------------------------------------------------------+\n    |                          yiaddr  (4)                          |\n    +---------------------------------------------------------------+\n    |                          siaddr  (4)                          |\n    +---------------------------------------------------------------+\n    |                          giaddr  (4)                          |\n    +---------------------------------------------------------------+\n    |                                                               |\n    |                          chaddr  (16)                         |\n    |                                                               |\n    |                                                               |\n    +---------------------------------------------------------------+\n    |                                                               |\n    |                          sname   (64)                         |\n    +---------------------------------------------------------------+\n    |                                                               |\n    |                          file    (128)                        |\n    +---------------------------------------------------------------+\n    |                                                               |\n    |                          options (variable)                   |\n    +---------------------------------------------------------------+\n\n\n DHCP defines a new 'client identifier' option that is used to pass an\n explicit client identifier to a DHCP server.  This change eliminates\n the overloading of the 'chaddr' field in BOOTP messages, where\n 'chaddr' is used both as a hardware address for transmission of BOOTP\n reply messages and as a client identifier.  The 'client identifier'\n is an opaque key, not to be interpreted by the server; for example,\n the 'client identifier' may contain a hardware address, identical to\n the contents of the 'chaddr' field, or it may contain another type of\n identifier, such as a DNS name.  The 'client identifier' chosen by a\n DHCP client MUST be unique to that client within the subnet to which\n the client is attached. If the client uses a 'client identifier' in\n one message, it MUST use that same identifier in all subsequent\n messages, to ensure that all servers correctly identify the client.\n\n DHCP clarifies the interpretation of the 'siaddr' field as the\n address of the server to use in the next step of the client's\n bootstrap process.  A DHCP server may return its own address in the\n 'siaddr' field, if the server is prepared to supply the next\n bootstrap service (e.g., delivery of an operating system executable\n image).  A DHCP server always returns its own address in the 'server\n identifier' option.\n\n    Description of fields in a DHCP message\n\n    FIELD      OCTETS       DESCRIPTION\n    -----      ------       -----------\n\n    op            1  Message op code / message type.\n                      1 = BOOTREQUEST, 2 = BOOTREPLY\n    htype         1  Hardware address type, see ARP section in \"Assigned\n                      Numbers\" RFC; e.g., '1' = 10mb ethernet.\n    hlen          1  Hardware address length (e.g.  '6' for 10mb\n                      ethernet).\n    hops          1  Client sets to zero, optionally used by relay agents\n                      when booting via a relay agent.\n    xid           4  Transaction ID, a random number chosen by the\n                      client, used by the client and server to associate\n                      messages and responses between a client and a\n                      server.\n    secs          2  Filled in by client, seconds elapsed since client\n                      began address acquisition or renewal process.\n    flags         2  Flags (see figure 2).\n    ciaddr        4  Client IP address; only filled in if client is in\n                      BOUND, RENEW or REBINDING state and can respond\n                      to ARP requests.\n    yiaddr        4  'your' (client) IP address.\n    siaddr        4  IP address of next server to use in bootstrap;\n                      returned in DHCPOFFER, DHCPACK by server.\n    giaddr        4  Relay agent IP address, used in booting via a\n                      relay agent.\n    chaddr       16  Client hardware address.\n    sname        64  Optional server host name, null terminated string.\n    file        128  Boot file name, null terminated string; \"generic\"\n                      name or null in DHCPDISCOVER, fully qualified\n                      directory-path name in DHCPOFFER.\n    options     var  Optional parameters field.  See the options\n                      documents for a list of defined options.\n\n The 'options' field is now variable length. A DHCP client must be\n prepared to receive DHCP messages with an 'options' field of at least\n length 312 octets.  This requirement implies that a DHCP client must\n be prepared to receive a message of up to 576 octets, the minimum IP\n datagram size an IP host must be prepared to accept [3].  DHCP\n clients may negotiate the use of larger DHCP messages through the\n 'maximum DHCP message size' option.  The options field may be further\n extended into the 'file' and 'sname' fields.\n\n In the case of a client using DHCP for initial configuration (before\n the client's TCP/IP software has been completely configured), DHCP\n requires creative use of the client's TCP/IP software and liberal\n interpretation of RFC 1122.  The TCP/IP software SHOULD accept and\n forward to the IP layer any IP packets delivered to the client's\n hardware address before the IP address is configured; DHCP servers\n and BOOTP relay agents may not be able to deliver DHCP messages to\n clients that cannot accept hardware unicast datagrams before the\n TCP/IP software is configured.\n\n To work around some clients that cannot accept IP unicast datagrams\n before the TCP/IP software is configured as discussed in the previous\n paragraph, DHCP uses the 'flags' field [21].  The leftmost bit is\n defined as the BROADCAST (B) flag.  The semantics of this flag are\n discussed in section 4.1 of this document.  The remaining bits of the\n flags field are reserved for future use.  They MUST be set to zero by\n clients and ignored by servers and relay agents.  Figure 2 gives the\n format of the 'flags' field.\n\n    Format of the 'flags' field\n\n                        1 1 1 1 1 1\n    0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5\n    +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n    |B|             MBZ             |\n    +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+\n\n    B:  BROADCAST flag\n\n    MBZ:  MUST BE ZERO (reserved for future use)","ref":"DHCP.Message.html"},{"type":"function","title":"DHCP.Message.from_iodata/1","doc":"","ref":"DHCP.Message.html#from_iodata/1"},{"type":"function","title":"DHCP.Message.new/0","doc":"","ref":"DHCP.Message.html#new/0"},{"type":"type","title":"DHCP.Message.t/0","doc":"","ref":"DHCP.Message.html#t:t/0"},{"type":"module","title":"DHCP.Message.Option","doc":"# DHCP Option\n\nDHCP Options and BOOTP Vendor Extensions [RFC2132](https://datatracker.ietf.org/doc/html/rfc2132)\n\nmagic cookie [link](https://datatracker.ietf.org/doc/html/rfc2132#section-2)\n\nWhen used with BOOTP, the first four octets of the vendor information\nfield have been assigned to the \"magic cookie\" (as suggested in RFC\n951).  This field identifies the mode in which the succeeding data is\nto be interpreted.  The value of the magic cookie is the 4 octet\ndotted decimal 99.130.83.99 (or hexadecimal number 63.82.53.63) in\nnetwork byte order.\n\n Pad Option\n\n The pad option can be used to cause subsequent fields to align on\n word boundaries.\n\n The code for the pad option is 0, and its length is 1 octet.\n\n      Code\n    +-----+\n    |  0  |\n    +-----+\n\n End Option\n\n The end option marks the end of valid information in the vendor\n field.  Subsequent octets should be filled with pad options.\n\n The code for the end option is 255, and its length is 1 octet.\n\n      Code\n    +-----+\n    | 255 |\n    +-----+\n\n**Subnet Mask**\n\n The subnet mask option specifies the client's subnet mask as per RFC\n 950 [5].\n\n If both the subnet mask and the router option are specified in a DHCP\n reply, the subnet mask option MUST be first.\n\n The code for the subnet mask option is 1, and its length is 4 octets.\n\n      Code   Len        Subnet Mask\n    +-----+-----+-----+-----+-----+-----+\n    |  1  |  4  |  m1 |  m2 |  m3 |  m4 |\n    +-----+-----+-----+-----+-----+-----+\n\n**Time Offset**\n\n The time offset field specifies the offset of the client's subnet in\n seconds from Coordinated Universal Time (UTC).  The offset is\n expressed as a two's complement 32-bit integer.  A positive offset\n indicates a location east of the zero meridian and a negative offset\n indicates a location west of the zero meridian.\n\n The code for the time offset option is 2, and its length is 4 octets.\n\n      Code   Len        Time Offset\n    +-----+-----+-----+-----+-----+-----+\n    |  2  |  4  |  n1 |  n2 |  n3 |  n4 |\n    +-----+-----+-----+-----+-----+-----+\n\n**Router Option**\n\n The router option specifies a list of IP addresses for routers on the\n client's subnet.  Routers SHOULD be listed in order of preference.\n\n The code for the router option is 3.  The minimum length for the\n router option is 4 octets, and the length MUST always be a multiple\n of 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    |  3  |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**Time Server Option**\n\n The time server option specifies a list of RFC 868 [6] time servers\n available to the client.  Servers SHOULD be listed in order of\n preference.\n\n The code for the time server option is 4.  The minimum length for\n this option is 4 octets, and the length MUST always be a multiple of\n 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    |  4  |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**Name Server Option**\n\n The name server option specifies a list of IEN 116 [7] name servers\n available to the client.  Servers SHOULD be listed in order of\n preference.\n\n The code for the name server option is 5.  The minimum length for\n this option is 4 octets, and the length MUST always be a multiple of\n 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    |  5  |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**Domain Name Server Option**\n\n The domain name server option specifies a list of Domain Name System\n (STD 13, RFC 1035 [8]) name servers available to the client.  Servers\n SHOULD be listed in order of preference.\n\n The code for the domain name server option is 6.  The minimum length\n for this option is 4 octets, and the length MUST always be a multiple\n of 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    |  6  |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**Log Server Option**\n\n The log server option specifies a list of MIT-LCS UDP log servers\n available to the client.  Servers SHOULD be listed in order of\n preference.\n\n The code for the log server option is 7.  The minimum length for this\n option is 4 octets, and the length MUST always be a multiple of 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    |  7  |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**Cookie Server Option**\n\n The cookie server option specifies a list of RFC 865 [9] cookie\n servers available to the client.  Servers SHOULD be listed in order\n of preference.\n\n The code for the log server option is 8.  The minimum length for this\n option is 4 octets, and the length MUST always be a multiple of 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    |  8  |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**LPR Server Option**\n\n The LPR server option specifies a list of RFC 1179 [10] line printer\n servers available to the client.  Servers SHOULD be listed in order\n of preference.\n\n The code for the LPR server option is 9.  The minimum length for this\n option is 4 octets, and the length MUST always be a multiple of 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    |  9  |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n      +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**Impress Server Option**\n\n The Impress server option specifies a list of Imagen Impress servers\n available to the client.  Servers SHOULD be listed in order of\n preference.\n\n The code for the Impress server option is 10.  The minimum length for\n this option is 4 octets, and the length MUST always be a multiple of\n 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    |  10 |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**Resource Location Server Option**\n\n This option specifies a list of RFC 887 [11] Resource Location\n servers available to the client.  Servers SHOULD be listed in order\n of preference.\n\n The code for this option is 11.  The minimum length for this option\n is 4 octets, and the length MUST always be a multiple of 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    |  11 |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**Host Name Option**\n\n This option specifies the name of the client.  The name may or may\n not be qualified with the local domain name (see section 3.17 for the\n preferred way to retrieve the domain name).  See RFC 1035 for\n character set restrictions.\n\n The code for this option is 12, and its minimum length is 1.\n\n      Code   Len                 Host Name\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    |  12 |  n  |  h1 |  h2 |  h3 |  h4 |  h5 |  h6 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**Boot File Size Option**\n\n This option specifies the length in 512-octet blocks of the default\n boot image for the client.  The file length is specified as an\n unsigned 16-bit integer.\n\n The code for this option is 13, and its length is 2.\n\n      Code   Len   File Size\n    +-----+-----+-----+-----+\n    |  13 |  2  |  l1 |  l2 |\n    +-----+-----+-----+-----+\n\n**Merit Dump File**\n\n This option specifies the path-name of a file to which the client's\n core image should be dumped in the event the client crashes.  The\n path is formatted as a character string consisting of characters from\n the NVT ASCII character set.\n\n The code for this option is 14.  Its minimum length is 1.\n\n      Code   Len      Dump File Pathname\n    +-----+-----+-----+-----+-----+-----+---\n    |  14 |  n  |  n1 |  n2 |  n3 |  n4 | ...\n    +-----+-----+-----+-----+-----+-----+---\n\n**Domain Name**\n\n This option specifies the domain name that client should use when\n resolving hostnames via the Domain Name System.\n\n The code for this option is 15.  Its minimum length is 1.\n\n      Code   Len        Domain Name\n    +-----+-----+-----+-----+-----+-----+--\n    |  15 |  n  |  d1 |  d2 |  d3 |  d4 |  ...\n    +-----+-----+-----+-----+-----+-----+--\n\n**Swap Server**\n\n This specifies the IP address of the client's swap server.\n\n The code for this option is 16 and its length is 4.\n\n      Code   Len    Swap Server Address\n    +-----+-----+-----+-----+-----+-----+\n    |  16 |  n  |  a1 |  a2 |  a3 |  a4 |\n    +-----+-----+-----+-----+-----+-----+\n\n**Root Path**\n\n This option specifies the path-name that contains the client's root\n disk.  The path is formatted as a character string consisting of\n characters from the NVT ASCII character set.\n\n The code for this option is 17.  Its minimum length is 1.\n\n      Code   Len      Root Disk Pathname\n    +-----+-----+-----+-----+-----+-----+---\n    |  17 |  n  |  n1 |  n2 |  n3 |  n4 | ...\n    +-----+-----+-----+-----+-----+-----+---\n\n**Extensions Path**\n\n A string to specify a file, retrievable via TFTP, which contains\n information which can be interpreted in the same way as the 64-octet\n vendor-extension field within the BOOTP response, with the following\n exceptions:\n\n        - the length of the file is unconstrained;\n        - all references to Tag 18 (i.e., instances of the\n          BOOTP Extensions Path field) within the file are\n          ignored.\n\n The code for this option is 18.  Its minimum length is 1.\n\n      Code   Len      Extensions Pathname\n    +-----+-----+-----+-----+-----+-----+---\n    |  18 |  n  |  n1 |  n2 |  n3 |  n4 | ...\n    +-----+-----+-----+-----+-----+-----+---\n\n**IP Forwarding Enable/Disable Option**\n\n This option specifies whether the client should configure its IP\n layer for packet forwarding.  A value of 0 means disable IP\n forwarding, and a value of 1 means enable IP forwarding.\n\n The code for this option is 19, and its length is 1.\n\n      Code   Len  Value\n    +-----+-----+-----+\n    |  19 |  1  | 0/1 |\n    +-----+-----+-----+\n\n**Non-Local Source Routing Enable/Disable Option**\n\n This option specifies whether the client should configure its IP\n layer to allow forwarding of datagrams with non-local source routes\n (see Section 3.3.5 of [4] for a discussion of this topic).  A value\n of 0 means disallow forwarding of such datagrams, and a value of 1\n means allow forwarding.\n\n The code for this option is 20, and its length is 1.\n\n      Code   Len  Value\n    +-----+-----+-----+\n    |  20 |  1  | 0/1 |\n    +-----+-----+-----+\n\n**Policy Filter Option**\n\n This option specifies policy filters for non-local source routing.\n The filters consist of a list of IP addresses and masks which specify\n destination/mask pairs with which to filter incoming source routes.\n\n Any source routed datagram whose next-hop address does not match one\n of the filters should be discarded by the client.\n\n See [4] for further information.\n\n The code for this option is 21.  The minimum length of this option is\n 8, and the length MUST be a multiple of 8.\n\n      Code   Len         Address 1                  Mask 1\n    +-----+-----+-----+-----+-----+-----+-----+-----+-----+-----+\n    |  21 |  n  |  a1 |  a2 |  a3 |  a4 |  m1 |  m2 |  m3 |  m4 |\n    +-----+-----+-----+-----+-----+-----+-----+-----+-----+-----+\n            Address 2                  Mask 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+---\n    |  a1 |  a2 |  a3 |  a4 |  m1 |  m2 |  m3 |  m4 | ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+---\n\n**Maximum Datagram Reassembly Size**\n\n This option specifies the maximum size datagram that the client\n should be prepared to reassemble.  The size is specified as a 16-bit\n unsigned integer.  The minimum value legal value is 576.\n\n The code for this option is 22, and its length is 2.\n\n      Code   Len      Size\n    +-----+-----+-----+-----+\n    |  22 |  2  |  s1 |  s2 |\n    +-----+-----+-----+-----+\n\n**Default IP Time-to-live**\n\n This option specifies the default time-to-live that the client should\n use on outgoing datagrams.  The TTL is specified as an octet with a\n value between 1 and 255.\n\n The code for this option is 23, and its length is 1.\n\n      Code   Len   TTL\n    +-----+-----+-----+\n    |  23 |  1  | ttl |\n    +-----+-----+-----+\n\n**Path MTU Aging Timeout Option**\n\n This option specifies the timeout (in seconds) to use when aging Path\n MTU values discovered by the mechanism defined in RFC 1191 [12].  The\n timeout is specified as a 32-bit unsigned integer.\n\n The code for this option is 24, and its length is 4.\n\n      Code   Len           Timeout\n    +-----+-----+-----+-----+-----+-----+\n    |  24 |  4  |  t1 |  t2 |  t3 |  t4 |\n    +-----+-----+-----+-----+-----+-----+\n\n**Path MTU Plateau Table Option**\n\n This option specifies a table of MTU sizes to use when performing\n Path MTU Discovery as defined in RFC 1191.  The table is formatted as\n a list of 16-bit unsigned integers, ordered from smallest to largest.\n The minimum MTU value cannot be smaller than 68.\n\n The code for this option is 25.  Its minimum length is 2, and the\n length MUST be a multiple of 2.\n\n      Code   Len     Size 1      Size 2\n    +-----+-----+-----+-----+-----+-----+---\n    |  25 |  n  |  s1 |  s2 |  s1 |  s2 | ...\n    +-----+-----+-----+-----+-----+-----+---\n\n**IP Layer Parameters per Interface**\n\n This section details the options that affect the operation of the IP\n layer on a per-interface basis.  It is expected that a client can\n issue multiple requests, one per interface, in order to configure\n interfaces with their specific parameters.\n\n**Interface MTU Option**\n\n This option specifies the MTU to use on this interface.  The MTU is\n specified as a 16-bit unsigned integer.  The minimum legal value for\n the MTU is 68.\n\n The code for this option is 26, and its length is 2.\n\n      Code   Len      MTU\n    +-----+-----+-----+-----+\n    |  26 |  2  |  m1 |  m2 |\n    +-----+-----+-----+-----+\n\n**All Subnets are Local Option**\n\n This option specifies whether or not the client may assume that all\n subnets of the IP network to which the client is connected use the\n same MTU as the subnet of that network to which the client is\n directly connected.  A value of 1 indicates that all subnets share\n the same MTU.  A value of 0 means that the client should assume that\n some subnets of the directly connected network may have smaller MTUs.\n\n The code for this option is 27, and its length is 1.\n\n      Code   Len  Value\n    +-----+-----+-----+\n    |  27 |  1  | 0/1 |\n    +-----+-----+-----+\n\n**Broadcast Address Option**\n\n This option specifies the broadcast address in use on the client's\n subnet.  Legal values for broadcast addresses are specified in\n section 3.2.1.3 of [4].\n\n The code for this option is 28, and its length is 4.\n\n      Code   Len     Broadcast Address\n    +-----+-----+-----+-----+-----+-----+\n    |  28 |  4  |  b1 |  b2 |  b3 |  b4 |\n    +-----+-----+-----+-----+-----+-----+\n\n**Perform Mask Discovery Option**\n\n This option specifies whether or not the client should perform subnet\n mask discovery using ICMP.  A value of 0 indicates that the client\n should not perform mask discovery.  A value of 1 means that the\n client should perform mask discovery.\n\n The code for this option is 29, and its length is 1.\n\n      Code   Len  Value\n    +-----+-----+-----+\n    |  29 |  1  | 0/1 |\n    +-----+-----+-----+\n\n**Mask Supplier Option**\n\n This option specifies whether or not the client should respond to\n subnet mask requests using ICMP.  A value of 0 indicates that the\n client should not respond.  A value of 1 means that the client should\n respond.\n\n The code for this option is 30, and its length is 1.\n\n      Code   Len  Value\n    +-----+-----+-----+\n    |  30 |  1  | 0/1 |\n    +-----+-----+-----+\n\n**Perform Router Discovery Option**\n\n This option specifies whether or not the client should solicit\n routers using the Router Discovery mechanism defined in RFC 1256\n [13].  A value of 0 indicates that the client should not perform\n router discovery.  A value of 1 means that the client should perform\n router discovery.\n\n The code for this option is 31, and its length is 1.\n\n      Code   Len  Value\n    +-----+-----+-----+\n    |  31 |  1  | 0/1 |\n    +-----+-----+-----+\n\n**Router Solicitation Address Option**\n\n This option specifies the address to which the client should transmit\n router solicitation requests.\n\n The code for this option is 32, and its length is 4.\n\n      Code   Len            Address\n    +-----+-----+-----+-----+-----+-----+\n    |  32 |  4  |  a1 |  a2 |  a3 |  a4 |\n    +-----+-----+-----+-----+-----+-----+\n\n**Static Route Option**\n\n This option specifies a list of static routes that the client should\n install in its routing cache.  If multiple routes to the same\n destination are specified, they are listed in descending order of\n priority.\n\n The routes consist of a list of IP address pairs.  The first address\n is the destination address, and the second address is the router for\n the destination.\n\n The default route (0.0.0.0) is an illegal destination for a static\n route.  See section 3.5 for information about the router option.\n\n The code for this option is 33.  The minimum length of this option is\n 8, and the length MUST be a multiple of 8.\n\n      Code   Len         Destination 1           Router 1\n    +-----+-----+-----+-----+-----+-----+-----+-----+-----+-----+\n    |  33 |  n  |  d1 |  d2 |  d3 |  d4 |  r1 |  r2 |  r3 |  r4 |\n    +-----+-----+-----+-----+-----+-----+-----+-----+-----+-----+\n            Destination 2           Router 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+---\n    |  d1 |  d2 |  d3 |  d4 |  r1 |  r2 |  r3 |  r4 | ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+---\n\n**Trailer Encapsulation Option**\n\n This option specifies whether or not the client should negotiate the\n use of trailers (RFC 893 [14]) when using the ARP protocol.  A value\n of 0 indicates that the client should not attempt to use trailers.  A\n value of 1 means that the client should attempt to use trailers.\n\n The code for this option is 34, and its length is 1.\n\n      Code   Len  Value\n    +-----+-----+-----+\n    |  34 |  1  | 0/1 |\n    +-----+-----+-----+\n\n**ARP Cache Timeout Option**\n\n This option specifies the timeout in seconds for ARP cache entries.\n The time is specified as a 32-bit unsigned integer.\n\n The code for this option is 35, and its length is 4.\n\n      Code   Len           Time\n    +-----+-----+-----+-----+-----+-----+\n    |  35 |  4  |  t1 |  t2 |  t3 |  t4 |\n    +-----+-----+-----+-----+-----+-----+\n\n**Ethernet Encapsulation Option**\n\n This option specifies whether or not the client should use Ethernet\n Version 2 (RFC 894 [15]) or IEEE 802.3 (RFC 1042 [16]) encapsulation\n if the interface is an Ethernet.  A value of 0 indicates that the\n client should use RFC 894 encapsulation.  A value of 1 means that the\n client should use RFC 1042 encapsulation.\n\n The code for this option is 36, and its length is 1.\n\n      Code   Len  Value\n    +-----+-----+-----+\n    |  36 |  1  | 0/1 |\n    +-----+-----+-----+\n\n**TCP Default TTL Option**\n\n This option specifies the default TTL that the client should use when\n sending TCP segments.  The value is represented as an 8-bit unsigned\n integer.  The minimum value is 1.\n\n The code for this option is 37, and its length is 1.\n\n      Code   Len   TTL\n    +-----+-----+-----+\n    |  37 |  1  |  n  |\n    +-----+-----+-----+\n\n**TCP Keepalive Interval Option**\n\n This option specifies the interval (in seconds) that the client TCP\n should wait before sending a keepalive message on a TCP connection.\n The time is specified as a 32-bit unsigned integer.  A value of zero\n indicates that the client should not generate keepalive messages on\n connections unless specifically requested by an application.\n\n The code for this option is 38, and its length is 4.\n\n      Code   Len           Time\n    +-----+-----+-----+-----+-----+-----+\n    |  38 |  4  |  t1 |  t2 |  t3 |  t4 |\n    +-----+-----+-----+-----+-----+-----+\n\n**TCP Keepalive Garbage Option**\n\n This option specifies the whether or not the client should send TCP\n keepalive messages with a octet of garbage for compatibility with\n older implementations.  A value of 0 indicates that a garbage octet\n should not be sent. A value of 1 indicates that a garbage octet\n should be sent.\n\n The code for this option is 39, and its length is 1.\n\n      Code   Len  Value\n    +-----+-----+-----+\n    |  39 |  1  | 0/1 |\n    +-----+-----+-----+\n\n**Network Information Service Domain Option**\n\n This option specifies the name of the client's NIS [17] domain.  The\n domain is formatted as a character string consisting of characters\n from the NVT ASCII character set.\n\n The code for this option is 40.  Its minimum length is 1.\n\n      Code   Len      NIS Domain Name\n    +-----+-----+-----+-----+-----+-----+---\n    |  40 |  n  |  n1 |  n2 |  n3 |  n4 | ...\n    +-----+-----+-----+-----+-----+-----+---\n\n**Network Information Servers Option**\n\n This option specifies a list of IP addresses indicating NIS servers\n available to the client.  Servers SHOULD be listed in order of\n preference.\n\n The code for this option is 41.  Its minimum length is 4, and the\n length MUST be a multiple of 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    |  41 |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**Network Time Protocol Servers Option**\n\n This option specifies a list of IP addresses indicating NTP [18]\n servers available to the client.  Servers SHOULD be listed in order\n of preference.\n\n The code for this option is 42.  Its minimum length is 4, and the\n length MUST be a multiple of 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    |  42 |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**Vendor Specific Information**\n\n This option is used by clients and servers to exchange vendor-\n specific information.  The information is an opaque object of n\n octets, presumably interpreted by vendor-specific code on the clients\n and servers.  The definition of this information is vendor specific.\n The vendor is indicated in the vendor class identifier option.\n Servers not equipped to interpret the vendor-specific information\n sent by a client MUST ignore it (although it may be reported).\n Clients which do not receive desired vendor-specific information\n SHOULD make an attempt to operate without it, although they may do so\n (and announce they are doing so) in a degraded mode.\n\n If a vendor potentially encodes more than one item of information in\n this option, then the vendor SHOULD encode the option using\n \"Encapsulated vendor-specific options\" as described below:\n\n The Encapsulated vendor-specific options field SHOULD be encoded as a\n sequence of code/length/value fields of identical syntax to the DHCP\n options field with the following exceptions:\n\n    1) There SHOULD NOT be a \"magic cookie\" field in the encapsulated\n       vendor-specific extensions field.\n\n    2) Codes other than 0 or 255 MAY be redefined by the vendor within\n       the encapsulated vendor-specific extensions field, but SHOULD\n       conform to the tag-length-value syntax defined in section 2.\n\n    3) Code 255 (END), if present, signifies the end of the\n       encapsulated vendor extensions, not the end of the vendor\n       extensions field. If no code 255 is present, then the end of\n       the enclosing vendor-specific information field is taken as the\n       end of the encapsulated vendor-specific extensions field.\n\n The code for this option is 43 and its minimum length is 1.\n\n    Code   Len   Vendor-specific information\n    +-----+-----+-----+-----+---\n    |  43 |  n  |  i1 |  i2 | ...\n    +-----+-----+-----+-----+---\n\n When encapsulated vendor-specific extensions are used, the\n information bytes 1-n have the following format:\n\n      Code   Len   Data item        Code   Len   Data item       Code\n    +-----+-----+-----+-----+-----+-----+-----+-----+-----+-----+-----+\n    |  T1 |  n  |  d1 |  d2 | ... |  T2 |  n  |  D1 |  D2 | ... | ... |\n    +-----+-----+-----+-----+-----+-----+-----+-----+-----+-----+-----+\n\n**NetBIOS over TCP/IP Name Server Option**\n\n The NetBIOS name server (NBNS) option specifies a list of RFC\n 1001/1002 [19] [20] NBNS name servers listed in order of preference.\n\n The code for this option is 44.  The minimum length of the option is\n 4 octets, and the length must always be a multiple of 4.\n\n      Code   Len           Address 1              Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+-----+-----+----\n    |  44 |  n  |  a1 |  a2 |  a3 |  a4 |  b1 |  b2 |  b3 |  b4 | ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+-----+-----+----\n\n**NetBIOS over TCP/IP Datagram Distribution Server Option**\n\n The NetBIOS datagram distribution server (NBDD) option specifies a\n list of RFC 1001/1002 NBDD servers listed in order of preference. The\n code for this option is 45.  The minimum length of the option is 4\n octets, and the length must always be a multiple of 4.\n\n      Code   Len           Address 1              Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+-----+-----+----\n    |  45 |  n  |  a1 |  a2 |  a3 |  a4 |  b1 |  b2 |  b3 |  b4 | ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+-----+-----+----\n\n**NetBIOS over TCP/IP Node Type Option**\n\n The NetBIOS node type option allows NetBIOS over TCP/IP clients which\n are configurable to be configured as described in RFC 1001/1002.  The\n value is specified as a single octet which identifies the client type\n as follows:\n\n    Value         Node Type\n    -----         ---------\n    0x1           B-node\n    0x2           P-node\n    0x4           M-node\n    0x8           H-node\n\n In the above chart, the notation '0x' indicates a number in base-16\n (hexadecimal).\n\n The code for this option is 46.  The length of this option is always\n 1.\n\n      Code   Len  Node Type\n    +-----+-----+-----------+\n    |  46 |  1  | see above |\n    +-----+-----+-----------+\n\n**NetBIOS over TCP/IP Scope Option**\n\n The NetBIOS scope option specifies the NetBIOS over TCP/IP scope\n parameter for the client as specified in RFC 1001/1002. See [19],\n [20], and [8] for character-set restrictions.\n\n The code for this option is 47.  The minimum length of this option is\n 1.\n\n      Code   Len       NetBIOS Scope\n    +-----+-----+-----+-----+-----+-----+----\n    |  47 |  n  |  s1 |  s2 |  s3 |  s4 | ...\n    +-----+-----+-----+-----+-----+-----+----\n\n**X Window System Font Server Option**\n\n This option specifies a list of X Window System [21] Font servers\n available to the client. Servers SHOULD be listed in order of\n preference.\n\n The code for this option is 48.  The minimum length of this option is\n 4 octets, and the length MUST be a multiple of 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+---\n    |  48 |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |   ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+---\n\n**X Window System Display Manager Option**\n\n This option specifies a list of IP addresses of systems that are\n running the X Window System Display Manager and are available to the\n client.\n\n Addresses SHOULD be listed in order of preference.\n\n The code for the this option is 49. The minimum length of this option\n is 4, and the length MUST be a multiple of 4.\n\n      Code   Len         Address 1               Address 2\n\n    +-----+-----+-----+-----+-----+-----+-----+-----+---\n    |  49 |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |   ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+---\n\n**Network Information Service+ Domain Option**\n\n This option specifies the name of the client's NIS+ [17] domain.  The\n domain is formatted as a character string consisting of characters\n from the NVT ASCII character set.\n\n The code for this option is 64.  Its minimum length is 1.\n\n      Code   Len      NIS Client Domain Name\n    +-----+-----+-----+-----+-----+-----+---\n    |  64 |  n  |  n1 |  n2 |  n3 |  n4 | ...\n    +-----+-----+-----+-----+-----+-----+---\n\n**Network Information Service+ Servers Option**\n\n This option specifies a list of IP addresses indicating NIS+ servers\n available to the client.  Servers SHOULD be listed in order of\n preference.\n\n The code for this option is 65.  Its minimum length is 4, and the\n length MUST be a multiple of 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    |  65 |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**Mobile IP Home Agent option**\n\n This option specifies a list of IP addresses indicating mobile IP\n home agents available to the client.  Agents SHOULD be listed in\n order of preference.\n\n The code for this option is 68.  Its minimum length is 0 (indicating\n no home agents are available) and the length MUST be a multiple of 4.\n It is expected that the usual length will be four octets, containing\n a single home agent's address.\n\n      Code Len    Home Agent Addresses (zero or more)\n    +-----+-----+-----+-----+-----+-----+--\n    | 68  |  n  | a1  | a2  | a3  | a4  | ...\n    +-----+-----+-----+-----+-----+-----+--\n\n**Simple Mail Transport Protocol (SMTP) Server Option**\n\n The SMTP server option specifies a list of SMTP servers available to\n the client.  Servers SHOULD be listed in order of preference.\n\n The code for the SMTP server option is 69.  The minimum length for\n this option is 4 octets, and the length MUST always be a multiple of\n 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    | 69  |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**Post Office Protocol (POP3) Server Option**\n\n The POP3 server option specifies a list of POP3 available to the\n client.  Servers SHOULD be listed in order of preference.\n\n The code for the POP3 server option is 70.  The minimum length for\n this option is 4 octets, and the length MUST always be a multiple of\n 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    | 70  |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**Network News Transport Protocol (NNTP) Server Option**\n\n The NNTP server option specifies a list of NNTP available to the\n client.  Servers SHOULD be listed in order of preference.\n\n The code for the NNTP server option is 71. The minimum length for\n this option is 4 octets, and the length MUST always be a multiple of\n 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    | 71  |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**Default World Wide Web (WWW) Server Option**\n\n The WWW server option specifies a list of WWW available to the\n client.  Servers SHOULD be listed in order of preference.\n\n The code for the WWW server option is 72.  The minimum length for\n this option is 4 octets, and the length MUST always be a multiple of\n 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    | 72  |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**Default Finger Server Option**\n\n The Finger server option specifies a list of Finger available to the\n client.  Servers SHOULD be listed in order of preference.\n\n The code for the Finger server option is 73.  The minimum length for\n this option is 4 octets, and the length MUST always be a multiple of\n 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    | 73  |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**Default Internet Relay Chat (IRC) Server Option**\n\n The IRC server option specifies a list of IRC available to the\n client.  Servers SHOULD be listed in order of preference.\n\n The code for the IRC server option is 74.  The minimum length for\n this option is 4 octets, and the length MUST always be a multiple of\n 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    | 74  |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**StreetTalk Server Option**\n\n The StreetTalk server option specifies a list of StreetTalk servers\n available to the client.  Servers SHOULD be listed in order of\n preference.\n\n The code for the StreetTalk server option is 75.  The minimum length\n for this option is 4 octets, and the length MUST always be a multiple\n of 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    | 75  |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**StreetTalk Directory Assistance (STDA) Server Option**\n\n The StreetTalk Directory Assistance (STDA) server option specifies a\n list of STDA servers available to the client.  Servers SHOULD be\n listed in order of preference.\n\n The code for the StreetTalk Directory Assistance server option is 76.\n The minimum length for this option is 4 octets, and the length MUST\n always be a multiple of 4.\n\n      Code   Len         Address 1               Address 2\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n    | 76  |  n  |  a1 |  a2 |  a3 |  a4 |  a1 |  a2 |  ...\n    +-----+-----+-----+-----+-----+-----+-----+-----+--\n\n**Requested IP Address**\n\n This option is used in a client request (DHCPDISCOVER) to allow the\n client to request that a particular IP address be assigned.\n\n The code for this option is 50, and its length is 4.\n\n      Code   Len          Address\n    +-----+-----+-----+-----+-----+-----+\n    |  50 |  4  |  a1 |  a2 |  a3 |  a4 |\n    +-----+-----+-----+-----+-----+-----+\n\n**IP Address Lease Time**\n\n This option is used in a client request (DHCPDISCOVER or DHCPREQUEST)\n to allow the client to request a lease time for the IP address.  In a\n server reply (DHCPOFFER), a DHCP server uses this option to specify\n the lease time it is willing to offer.\n\n The time is in units of seconds, and is specified as a 32-bit\n unsigned integer.\n\n The code for this option is 51, and its length is 4.\n\n      Code   Len         Lease Time\n    +-----+-----+-----+-----+-----+-----+\n    |  51 |  4  |  t1 |  t2 |  t3 |  t4 |\n    +-----+-----+-----+-----+-----+-----+\n\n**Option Overload**\n\n This option is used to indicate that the DHCP 'sname' or 'file'\n fields are being overloaded by using them to carry DHCP options. A\n DHCP server inserts this option if the returned parameters will\n exceed the usual space allotted for options.\n\n If this option is present, the client interprets the specified\n additional fields after it concludes interpretation of the standard\n option fields.\n\n The code for this option is 52, and its length is 1.  Legal values\n for this option are:\n\n         Value   Meaning\n         -----   --------\n           1     the 'file' field is used to hold options\n           2     the 'sname' field is used to hold options\n           3     both fields are used to hold options\n\n      Code   Len  Value\n    +-----+-----+-----+\n    |  52 |  1  |1/2/3|\n    +-----+-----+-----+\n\n**TFTP server name**\n\n This option is used to identify a TFTP server when the 'sname' field\n in the DHCP header has been used for DHCP options.\n\n The code for this option is 66, and its minimum length is 1.\n\n     Code  Len   TFTP server\n    +-----+-----+-----+-----+-----+---\n    | 66  |  n  |  c1 |  c2 |  c3 | ...\n    +-----+-----+-----+-----+-----+---\n\n**Bootfile name**\n\n This option is used to identify a bootfile when the 'file' field in\n the DHCP header has been used for DHCP options.\n\n The code for this option is 67, and its minimum length is 1.\n\n     Code  Len   Bootfile name\n    +-----+-----+-----+-----+-----+---\n    | 67  |  n  |  c1 |  c2 |  c3 | ...\n    +-----+-----+-----+-----+-----+---\n\n**DHCP Message Type**\n\n This option is used to convey the type of the DHCP message.  The code\n for this option is 53, and its length is 1.  Legal values for this\n option are:\n\n         Value   Message Type\n         -----   ------------\n           1     DHCPDISCOVER\n           2     DHCPOFFER\n           3     DHCPREQUEST\n           4     DHCPDECLINE\n           5     DHCPACK\n           6     DHCPNAK\n           7     DHCPRELEASE\n           8     DHCPINFORM\n\n      Code   Len  Type\n    +-----+-----+-----+\n    |  53 |  1  | 1-9 |\n    +-----+-----+-----+\n\n**Server Identifier**\n\n This option is used in DHCPOFFER and DHCPREQUEST messages, and may\n optionally be included in the DHCPACK and DHCPNAK messages.  DHCP\n servers include this option in the DHCPOFFER in order to allow the\n client to distinguish between lease offers.  DHCP clients use the\n contents of the 'server identifier' field as the destination address\n for any DHCP messages unicast to the DHCP server.  DHCP clients also\n indicate which of several lease offers is being accepted by including\n this option in a DHCPREQUEST message.\n\n The identifier is the IP address of the selected server.\n\n The code for this option is 54, and its length is 4.\n\n      Code   Len            Address\n    +-----+-----+-----+-----+-----+-----+\n    |  54 |  4  |  a1 |  a2 |  a3 |  a4 |\n    +-----+-----+-----+-----+-----+-----+\n\n**Parameter Request List**\n\n This option is used by a DHCP client to request values for specified\n configuration parameters.  The list of requested parameters is\n specified as n octets, where each octet is a valid DHCP option code\n as defined in this document.\n\n The client MAY list the options in order of preference.  The DHCP\n server is not required to return the options in the requested order,\n but MUST try to insert the requested options in the order requested\n by the client.\n\n The code for this option is 55.  Its minimum length is 1.\n\n      Code   Len   Option Codes\n    +-----+-----+-----+-----+---\n    |  55 |  n  |  c1 |  c2 | ...\n    +-----+-----+-----+-----+---\n\n**Message**\n\n This option is used by a DHCP server to provide an error message to a\n DHCP client in a DHCPNAK message in the event of a failure. A client\n may use this option in a DHCPDECLINE message to indicate the why the\n client declined the offered parameters.  The message consists of n\n octets of NVT ASCII text, which the client may display on an\n available output device.\n\n The code for this option is 56 and its minimum length is 1.\n\n      Code   Len     Text\n    +-----+-----+-----+-----+---\n    |  56 |  n  |  c1 |  c2 | ...\n    +-----+-----+-----+-----+---\n\n**Maximum DHCP Message Size**\n\n This option specifies the maximum length DHCP message that it is\n willing to accept.  The length is specified as an unsigned 16-bit\n integer.  A client may use the maximum DHCP message size option in\n DHCPDISCOVER or DHCPREQUEST messages, but should not use the option\n in DHCPDECLINE messages.\n\n The code for this option is 57, and its length is 2.  The minimum\n legal value is 576 octets.\n\n      Code   Len     Length\n    +-----+-----+-----+-----+\n    |  57 |  2  |  l1 |  l2 |\n    +-----+-----+-----+-----+\n\n**Renewal (T1) Time Value**\n\n This option specifies the time interval from address assignment until\n the client transitions to the RENEWING state.\n\n The value is in units of seconds, and is specified as a 32-bit\n unsigned integer.\n\n The code for this option is 58, and its length is 4.\n\n      Code   Len         T1 Interval\n    +-----+-----+-----+-----+-----+-----+\n    |  58 |  4  |  t1 |  t2 |  t3 |  t4 |\n    +-----+-----+-----+-----+-----+-----+\n\n**Rebinding (T2) Time Value**\n\n This option specifies the time interval from address assignment until\n the client transitions to the REBINDING state.\n\n The value is in units of seconds, and is specified as a 32-bit\n unsigned integer.\n\n The code for this option is 59, and its length is 4.\n\n      Code   Len         T2 Interval\n    +-----+-----+-----+-----+-----+-----+\n    |  59 |  4  |  t1 |  t2 |  t3 |  t4 |\n    +-----+-----+-----+-----+-----+-----+\n\n**Vendor class identifier**\n\n This option is used by DHCP clients to optionally identify the vendor\n type and configuration of a DHCP client.  The information is a string\n of n octets, interpreted by servers.  Vendors may choose to define\n specific vendor class identifiers to convey particular configuration\n or other identification information about a client.  For example, the\n identifier may encode the client's hardware configuration.  Servers\n not equipped to interpret the class-specific information sent by a\n client MUST ignore it (although it may be reported). Servers that\n\n respond SHOULD only use option 43 to return the vendor-specific\n information to the client.\n\n The code for this option is 60, and its minimum length is 1.\n\n    Code   Len   Vendor class Identifier\n    +-----+-----+-----+-----+---\n    |  60 |  n  |  i1 |  i2 | ...\n    +-----+-----+-----+-----+---\n\n**Client-identifier**\n\n This option is used by DHCP clients to specify their unique\n identifier.  DHCP servers use this value to index their database of\n address bindings.  This value is expected to be unique for all\n clients in an administrative domain.\n\n Identifiers SHOULD be treated as opaque objects by DHCP servers.\n\n The client identifier MAY consist of type-value pairs similar to the\n 'htype'/'chaddr' fields defined in [3]. For instance, it MAY consist\n of a hardware type and hardware address. In this case the type field\n SHOULD be one of the ARP hardware types defined in -old STD2-\n [RFC1700](https://datatracker.ietf.org/doc/html/rfc1700) replaced by\n [New IANA online database](https://www.iana.org/assignments/arp-parameters/arp-parameters.xhtml#hardware-types).\n A hardware type of 0 (zero) should be used when the value field\n contains an identifier other than a hardware address (e.g. a fully\n qualified domain name).\n\n For correct identification of clients, each client's client-\n identifier MUST be unique among the client-identifiers used on the\n subnet to which the client is attached.  Vendors and system\n administrators are responsible for choosing client-identifiers that\n meet this requirement for uniqueness.\n\n The code for this option is 61, and its minimum length is 2.\n\n    Code   Len   Type  Client-Identifier\n    +-----+-----+-----+-----+-----+---\n    |  61 |  n  |  t1 |  i1 |  i2 | ...\n    +-----+-----+-----+-----+-----+---","ref":"DHCP.Message.Option.html"},{"type":"function","title":"DHCP.Message.Option.decode_option_value/3","doc":"","ref":"DHCP.Message.Option.html#decode_option_value/3"},{"type":"function","title":"DHCP.Message.Option.from_iodata/1","doc":"","ref":"DHCP.Message.Option.html#from_iodata/1"},{"type":"function","title":"DHCP.Message.Option.new/3","doc":"","ref":"DHCP.Message.Option.html#new/3"},{"type":"function","title":"DHCP.Message.Option.parse/1","doc":"","ref":"DHCP.Message.Option.html#parse/1"},{"type":"type","title":"DHCP.Message.Option.t/0","doc":"","ref":"DHCP.Message.Option.html#t:t/0"},{"type":"function","title":"DHCP.Message.Option.to_dhcp_binary/1","doc":"","ref":"DHCP.Message.Option.html#to_dhcp_binary/1"},{"type":"protocol","title":"DHCP.Parameter","doc":"","ref":"DHCP.Parameter.html"},{"type":"type","title":"DHCP.Parameter.t/0","doc":"All the types that implement this protocol.","ref":"DHCP.Parameter.html#t:t/0"},{"type":"function","title":"DHCP.Parameter.to_iodata/1","doc":"","ref":"DHCP.Parameter.html#to_iodata/1"},{"type":"extras","title":"DHCP","doc":"# DHCP\n\n[![release](https://github.com/gsmlg-dev/ex_dhcp/actions/workflows/release.yml/badge.svg)](https://github.com/gsmlg-dev/ex_dhcp/actions/workflows/release.yml) \n[![Hex.pm](https://img.shields.io/hexpm/v/ex_dhcp.svg)](https://hex.pm/packages/ex_dhcp) \n[![Documentation](https://img.shields.io/badge/documentation-gray)](https://hexdocs.pm/ex_dhcp)\n\n---","ref":"readme.html"},{"type":"extras","title":"Installation - DHCP","doc":"The package can be installed by adding `dhcp_ex` to your list of dependencies in `mix.exs`:\n\n ```elixir\ndef deps do\n  [\n    {:dhcp_ex, \"~> 0.3.0\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}